<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_CN" version="2.1">
<context>
    <name>CDayMonthView</name>
    <message>
        <source>Monday</source>
        <translation>星期一</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>星期二</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>星期三</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>星期四</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>星期五</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>星期六</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>星期天</translation>
    </message>
</context>
<context>
    <name>CDayWindow</name>
    <message>
        <source>Y</source>
        <translation>年</translation>
    </message>
    <message>
        <source>M</source>
        <translation>月</translation>
    </message>
    <message>
        <source>D</source>
        <translation>日</translation>
    </message>
</context>
<context>
    <name>CGraphicsView</name>
    <message>
        <source>New Event</source>
        <translation>新建日程</translation>
    </message>
</context>
<context>
    <name>CMonthGraphiview</name>
    <message>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <source>You are deleting an event.</source>
        <translation>您正在删除日程。</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this event?</source>
        <translation>您确定要删除此日程吗？</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Do you want to delete all occurrences of this event, or only the selected occurrence?</source>
        <translation>您要删除此日程的所有重复，还是只删除所选重复？</translation>
    </message>
    <message>
        <source>Delete All</source>
        <translation>全部删除</translation>
    </message>
    <message>
        <source>Delete Only This Event</source>
        <translation>仅删除此日程</translation>
    </message>
    <message>
        <source>Do you want to delete this and all future occurrences of this event, or only the selected occurrence?</source>
        <translation>您要删除此日程的这个重复和所有将来重复，还是只删除所选重复？</translation>
    </message>
    <message>
        <source>Delete All Future Events</source>
        <translation>删除所有将来日程</translation>
    </message>
</context>
<context>
    <name>CMonthSchceduleNumButton</name>
    <message>
        <source>%1 more</source>
        <translation>还有%1项</translation>
    </message>
</context>
<context>
    <name>CMonthView</name>
    <message>
        <source>New event</source>
        <translation>新建日程</translation>
    </message>
    <message>
        <source>New Event</source>
        <translation>新建日程</translation>
    </message>
</context>
<context>
    <name>CMonthWindow</name>
    <message>
        <source>Y</source>
        <translation>年</translation>
    </message>
</context>
<context>
    <name>CMySchceduleView</name>
    <message>
        <source>You are deleting an event.</source>
        <translation>您正在删除日程。</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this event?</source>
        <translation>您确定要删除此日程吗？</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <source>Do you want to delete all occurrences of this event, or only the selected occurrence?</source>
        <translation>您要删除此日程的所有重复，还是只删除所选重复？</translation>
    </message>
    <message>
        <source>Delete All</source>
        <translation>全部删除</translation>
    </message>
    <message>
        <source>Delete Only This Event</source>
        <translation>仅删除此日程</translation>
    </message>
    <message>
        <source>Do you want to delete this and all future occurrences of this event, or only the selected occurrence?</source>
        <translation>您要删除此日程的这个重复和所有将来重复，还是只删除所选重复？</translation>
    </message>
    <message>
        <source>My Event</source>
        <translation>我的日程</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>编辑</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>确定</translation>
    </message>
    <message>
        <source>Delete All Future Events</source>
        <translation>删除所有将来日程</translation>
    </message>
</context>
<context>
    <name>CSchceduleDlg</name>
    <message>
        <source>New Event</source>
        <translation>新建日程</translation>
    </message>
    <message>
        <source>Edit Event</source>
        <translation>编辑日程</translation>
    </message>
    <message>
        <source>All occurrences of a repeating event must have the same all-day status.</source>
        <translation>重复日程的所有重复必须具有相同的全天状态。</translation>
    </message>
    <message>
        <source>Do you want to change all occurrences?</source>
        <translation>您要更改所有重复吗？</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Change All</source>
        <translation>全部更改</translation>
    </message>
    <message>
        <source>You are changing the repeating rule of this event.</source>
        <translation>您正在更改日程的重复规则。</translation>
    </message>
    <message>
        <source>You are changing a repeating event.</source>
        <translation>您正在更改重复日程。</translation>
    </message>
    <message>
        <source>Do you want to change only this occurrence of the event, or all occurrences?</source>
        <translation>您要更改此日程的仅这一个重复，还是更改它的所有重复？</translation>
    </message>
    <message>
        <source>All</source>
        <translation>全部日程</translation>
    </message>
    <message>
        <source>Only This Event</source>
        <translation>仅此日程</translation>
    </message>
    <message>
        <source>Do you want to change only this occurrence of the event, or this and all future occurrences?</source>
        <translation>您要更改此日程的这个重复和所有将来重复，还是只更改所选重复？</translation>
    </message>
    <message>
        <source>All Future Events</source>
        <translation>所有将来日程</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>从不</translation>
    </message>
    <message>
        <source>At time of event</source>
        <translation>日程开始时</translation>
    </message>
    <message>
        <source>15 minutes before</source>
        <translation>15分钟前</translation>
    </message>
    <message>
        <source>30 minutes before</source>
        <translation>30分钟前</translation>
    </message>
    <message>
        <source>1 hour before</source>
        <translation>1小时前</translation>
    </message>
    <message>
        <source>1 day before</source>
        <translation>1天前</translation>
    </message>
    <message>
        <source>2 days before</source>
        <translation>2天前</translation>
    </message>
    <message>
        <source>1 week before</source>
        <translation>1周前</translation>
    </message>
    <message>
        <source>On start day (9:00 AM)</source>
        <translation>日程发生当天（上午9点）</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>类型：</translation>
    </message>
    <message>
        <source>All Day:</source>
        <translation>全天：</translation>
    </message>
    <message>
        <source>Remind Me:</source>
        <translation>提醒：</translation>
    </message>
    <message>
        <source>Repeat:</source>
        <translation>重复：</translation>
    </message>
    <message>
        <source>Daily</source>
        <translation>每天</translation>
    </message>
    <message>
        <source>Weekdays</source>
        <translation>工作日</translation>
    </message>
    <message>
        <source>Weekly</source>
        <translation>每周</translation>
    </message>
    <message>
        <source>Monthly</source>
        <translation>每月</translation>
    </message>
    <message>
        <source>Yearly</source>
        <translation>每年</translation>
    </message>
    <message>
        <source>End Repeat:</source>
        <translation>结束重复：</translation>
    </message>
    <message>
        <source>After</source>
        <translation>于</translation>
    </message>
    <message>
        <source>On</source>
        <translation>于日期</translation>
    </message>
    <message>
        <source>time(s)</source>
        <translation>次后</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <source>New event</source>
        <translation>新建日程</translation>
    </message>
    <message>
        <source>End time must be greater than start time</source>
        <translation>结束时间需晚于开始时间</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>确定</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>类型</translation>
    </message>
    <message>
        <source>All Day</source>
        <translation>全天</translation>
    </message>
    <message>
        <source>Starts</source>
        <translation>开始时间</translation>
    </message>
    <message>
        <source>Ends</source>
        <translation>结束时间</translation>
    </message>
    <message>
        <source>Remind Me</source>
        <translation>提醒</translation>
    </message>
    <message>
        <source>Repeat</source>
        <translation>重复</translation>
    </message>
    <message>
        <source>End Repeat</source>
        <translation>结束重复</translation>
    </message>
    <message>
        <source>Ends:</source>
        <translation>结束时间：</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>内容：</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>内容</translation>
    </message>
    <message>
        <source>Starts:</source>
        <translation>开始时间：</translation>
    </message>
    <message>
        <source>Work</source>
        <translation>工作</translation>
    </message>
    <message>
        <source>Life</source>
        <translation>生活</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>其他</translation>
    </message>
</context>
<context>
    <name>CSchceduleSearchDateItem</name>
    <message>
        <source>Y</source>
        <translation>年</translation>
    </message>
    <message>
        <source>M</source>
        <translation>月</translation>
    </message>
    <message>
        <source>D</source>
        <translation>日</translation>
    </message>
</context>
<context>
    <name>CSchceduleSearchItem</name>
    <message>
        <source>Edit</source>
        <translation>编辑</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <source>You are deleting an event.</source>
        <translation>您正在删除日程。</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this event?</source>
        <translation>您确定要删除此日程吗？</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Do you want to delete all occurrences of this event, or only the selected occurrence?</source>
        <translation>您要删除此日程的所有重复，还是只删除所选重复？</translation>
    </message>
    <message>
        <source>Delete All</source>
        <translation>全部删除</translation>
    </message>
    <message>
        <source>Delete Only This Event</source>
        <translation>仅删除此日程</translation>
    </message>
    <message>
        <source>Do you want to delete this and all future occurrences of this event, or only the selected occurrence?</source>
        <translation>您要删除此日程的这个重复和所有将来重复，还是只删除所选重复？</translation>
    </message>
    <message>
        <source>Delete All Future Events</source>
        <translation>删除所有将来日程</translation>
    </message>
    <message>
        <source>All Day</source>
        <translation>全天</translation>
    </message>
</context>
<context>
    <name>CSchceduleSearchView</name>
    <message>
        <source>No search results</source>
        <translation>无搜索结果</translation>
    </message>
</context>
<context>
    <name>CScheduleView</name>
    <message>
        <source>ALL DAY</source>
        <translation>全天</translation>
    </message>
</context>
<context>
    <name>CWeekWindow</name>
    <message>
        <source>Week</source>
        <translation>周</translation>
    </message>
    <message>
        <source>Y</source>
        <translation>年</translation>
    </message>
</context>
<context>
    <name>CYearSchceduleItem</name>
    <message>
        <source>All Day</source>
        <translation>全天</translation>
    </message>
</context>
<context>
    <name>CYearSchceduleView</name>
    <message>
        <source>All Day</source>
        <translation>全天</translation>
    </message>
    <message>
        <source>No event</source>
        <translation>无日程</translation>
    </message>
</context>
<context>
    <name>CYearWindow</name>
    <message>
        <source>Y</source>
        <translation>年</translation>
    </message>
</context>
<context>
    <name>CalendarWindow</name>
    <message>
        <source>Calendar</source>
        <translation>日历</translation>
    </message>
    <message>
        <source>Calendar is a tool to view dates, and also a smart daily planner to schedule all things in life. </source>
        <translation>日历是一款查看日期、管理日程的小工具。</translation>
    </message>
</context>
<context>
    <name>Calendarmainwindow</name>
    <message>
        <source>Calendar</source>
        <translation>日历</translation>
    </message>
    <message>
        <source>Y</source>
        <translation>年</translation>
    </message>
    <message>
        <source>M</source>
        <translation>月</translation>
    </message>
    <message>
        <source>W</source>
        <translation>周</translation>
    </message>
    <message>
        <source>D</source>
        <translation>日</translation>
    </message>
</context>
<context>
    <name>CenterWidget</name>
    <message>
        <source>All Day</source>
        <translation>全天</translation>
    </message>
</context>
<context>
    <name>DragInfoGraphicsView</name>
    <message>
        <source>Edit</source>
        <translation>编辑</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <source>New event</source>
        <translation>新建日程</translation>
    </message>
    <message>
        <source>You are deleting an event.</source>
        <translation>您正在删除日程。</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this event?</source>
        <translation>您确定要删除此日程吗？</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Do you want to delete all occurrences of this event, or only the selected occurrence?</source>
        <translation>您要删除此日程的所有重复，还是只删除所选重复？</translation>
    </message>
    <message>
        <source>Delete All</source>
        <translation>全部删除</translation>
    </message>
    <message>
        <source>Delete Only This Event</source>
        <translation>仅删除此日程</translation>
    </message>
    <message>
        <source>Do you want to delete this and all future occurrences of this event, or only the selected occurrence?</source>
        <translation>您要删除此日程的这个重复和所有将来重复，还是只删除所选重复？</translation>
    </message>
    <message>
        <source>Delete All Future Events</source>
        <translation>删除所有将来日程</translation>
    </message>
    <message>
        <source>New Event</source>
        <translation>新建日程</translation>
    </message>
</context>
<context>
    <name>Return</name>
    <message>
        <source>Today</source>
        <comment>Return</comment>
        <translation>返回今天</translation>
    </message>
</context>
<context>
    <name>Return Today</name>
    <message>
        <source>Today</source>
        <comment>Return Today</comment>
        <translation>返回今天</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>帮助</translation>
    </message>
    <message>
        <source>Delete event</source>
        <translation>删除日程</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>复制</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>剪切</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>粘贴</translation>
    </message>
    <message>
        <source>Select all</source>
        <translation>全选</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
</context>
<context>
    <name>YearFrame</name>
    <message>
        <source>Y</source>
        <translation>年</translation>
    </message>
</context>
<context>
    <name>today</name>
    <message>
        <source>Today</source>
        <comment>Today</comment>
        <translation>今天</translation>
    </message>
</context>
</TS>